/* **********************************************************************************************************
 *	Das Modul beinhaltet einige Konvertierungs Funktionen zwischen den
 * Koordinatensystemen.
 * The module includes some conversion functions between the
 * Coordinate systems .
 *
 *
 *	Funktionsliste - Function list:
 *
 *		- equ2Hor()										Konvertiert quatrorial Koordinaten zu
 *		 														zu horizontal Koordinaten.
 * 																Convert equatrorial Coordinates to
 * 																to horizontal coordinates.
 *		- equ2HorAZ()									Konvertiert quatrorial Koordinaten zu
 *																zu horizontalem Azimuth.
 *																Convert equatrorial coordinates to
 *                                              				to horizontal azimuth.
 *		- equ2HorAlt()									Konvertiert quatroriale Koordinaten zu
 *																zu horizontaler Hhe.
 *																Convert equatrorial coordinates to
 *																to horizontal altitude.
 *		- convertEquatorial2HorizontalAZ()	Alter Funktionsname, funktioniert fehlerhaft
 *																Old function name, working incorrectly
 *		- convertEquatorial2HorizontalAlt()	Alter Funktionsname, funktioniert fehlerhaft
 *																Old function name, working incorrectly
 *		- convertEquatorial2Horizontal()		Alter Funktionsname, funktioniert fehlerhaft
 *																Old function name, working incorrectly
 *		- convertEquatorial2Ecliptic()			Fehlerhafte Funktion - 
 *																Berechnet ekliptische Koordinaten aus
 *																quatorialen Koordinaten.
 *																Calculates ecliptic coordinates from
 *																equatorial coordinates.
 *
 *	02.04.2021, Dieter Steffan	Erstellung der Funktionen
 *	24.20.2022	Dieter Steffan	Update der Funktionen
 *
 ****************************************************************************************************************/

function eclip2EquRaDec(eclipLambda, eclipBeta, day, month, year){
	var LDM = Number(eclipLambda);
	var BM = Number(eclipBeta);
	var jdDay = parseInt(day);
	var jdMonth = parseInt(month);
	var jdYear = parseInt(year);
	var Ret = [];
	// Berechnung der quatorial Koordinaten RA und Dec  aus dem ekliptischen Lngengrad Lambda und
	// der ekliptischen Breite Beta zu dem Berechnungszeitpunkt ...
	// Calculation of the equatorial coordinates RA and Dec from the ecliptic longitude lambda and
	// the ecliptic latitude beta at the time of calculation ...
	var equRA = eclipticCoords2EquatorialRA(LDM, 0, 0, BM, 0, 0, jdDay, jdMonth, jdYear);
	var equDec = eclipticCoords2EquatorialDec(LDM, 0, 0, BM, 0, 0, jdDay, jdMonth, jdYear);
	// Als nchstes berechnen wir die rechteckigen Ekliptikkoordinaten des Mondes und rotieren sie, um rechtwinckelige
	// quatorialkoordinaten ...
	// Next we calculate the rectangular ecliptic coordinates of the Moon and rotate them to right-angled
	// Equatorial coordinates ...
	var xm2eclip = (1 * Math.cos(LDM / RAD) * Math. cos(BM / RAD)).toFixed(6);
	var ym2eclip = (1 * Math.sin(LDM / RAD) * Math.cos(BM / RAD)).toFixed(6);
	var zm2eclip = (1 * Math.sin(BM / RAD)).toFixed(6);
	// Berechnung der ekliptischen Schiefe ...
	// Calculation of the ecliptic slope ...
	var oblecl = eclipticObliquity(jdDay, jdMonth, jdYear);
	// Rotieren in rechtwinkelige ekliptischen Koordinaten in quatoriale Koordinaten
	var xm2equat = xm2eclip;
	var ym2equat = (ym2eclip * Math.cos(oblecl / RAD) - zm2eclip * Math.sin(oblecl / RAD)).toFixed(6);
	var zm2equat = (ym2eclip * Math.sin(oblecl / RAD) + zm2eclip * Math.cos(oblecl / RAD)).toFixed(6);
	// Und dann geozentrische RA und Dec berechnen ...
	// And then calculate geocentric RA and Dec ...
	var geoRA   = Math.atan2( ym2equat, xm2equat );
	geoRA = unwindDeg(geoRA * RAD).toFixed(4);
	Ret.push(geoRA);
	// Berechnung der geozentrischen Deklination aus den quatorial-Koordinaten ...
	// Calculation of the geocentric declination from the equatorial coordinates ...
	var geoDecl = ((Math.atan2( zm2equat, Math.sqrt( xm2equat*xm2equat + ym2equat*ym2equat ) )) * RAD).toFixed(4);
	Ret.push(geoDecl);
	
	return(Ret);
	
}// End of eclip2EquRaDec()



function equ2Hor(geoRA, geoDecl, glatDeg, glongDeg, JDLT, jdYear, UT){
	var RET = new Array();									// Der Rckgabewert

	// Berechnung des Teils des vergangenen Jahrhunderts als Dezimalzahl von 0.0 - 1.0 ...
	// Calculate the part of the last century as a decimal from 0.0  1.0 ...
	var T = partOfTheCentury(jdYear, JDLT);
	// Berechnung der Sternzeit in Greenwich um 0h ...
	// Calculation of the stardate in Greenwich at 0h ...
	var GMST0 =  100.46061837 + (36000.770053608 * Number(T[1])) + (0.000387933 * Math.pow(Number(T[1]), 2)) - (Math.pow(Number(T[1]), 3) / 38710000);
	GMST0 = unwindDeg(GMST0 + (15 * (1.00273790935 * UT)));
	// Berechnung der lokalen Sternzeit am Ort der Beobachtung ...
	// Calculation of the local stardate at the place of observation ...
	var LMSTG = unwindDeg(Number(GMST0) + Number(glongDeg));
	// Berechnung der X/Y-Werte fr die tan()-Funktion des Azimuths ...
	// Calculation of the X/Y values for the tan () function of the azimuth ...
	//x = -(Math.cos(glatDeg / RAD) * Math.sin(geoDecl / RAD) ) + ( Math.sin(glatDeg / RAD) * Math.cos(geoDecl / RAD) * Math.cos( (LMSTG - geoRA) / RAD ) );
	//y = Math.cos(geoDecl / RAD) * Math.sin( (LMSTG - geoRA) / RAD );
	var dy = ( Math.sin( (LMSTG - geoRA) / RAD) );
	var dx = ( Math.sin(glatDeg / RAD) * Math.cos( (LMSTG - geoRA) / RAD )) - (Math.cos(glatDeg / RAD) * Math.tan(geoDecl / RAD) );
	// Korrektur des Ergebnisses, da bein Tangens die Quadranten I. + III. sowie II. + IV. dieselben Werte ergeben.
	// Es muss nach Quadrant selektiert werden und dazu werden der Y-Wert und der X-Wert verwendet ...
	// Correction of the result, since tangent the quadrants I. + III. and II. + IV. give the same values.
	// It must be selected by quadrant using the Y-value and the X-value ...
	var AZ = 0.0;
	// I. Quadrant
	if ( dx > 0.0 && dy > 0.0){ 
		AZ = (Math.atan( dy / dx) + Math.PI) * RAD;
	// II. Quadrant
	}else if ( dx < 0.0 && dy > 0.0){
		AZ = (Math.atan( dy / dx) + (2 * Math.PI)) * RAD;
	// III. Quadrant
	}else if ( dx < 0.0 && dy < 0.0){
		AZ = Math.atan( dy / dx)  * RAD;
	// IV. Quadrant
	}else if ( dx > 0.0 && dy < 0.0){
		AZ = (Math.atan( dy / dx) + Math.PI) * RAD;
	}
	// ... dann noch die Sonderflle der Null-Werte bei X und Y, da die Tangenswerte unendlich werden ...
	// ... then the special cases of the zero values at X and Y, since the tangent values become infinite ...
	if (dx == 0.&& dy > 0.0)
		AZ = 90.0;
	else if (dx == 0.0 && dy < 0.0)
		AZ = 180.0;
	else if (dx < 0.0 && dy == 0.0)
		AZ =  270.0;
	else if ( dx > 0.0 && dy == 0.0)
		AZ =  360.0;
	// ... Azimuth ins Array ...
	// . . . Azimuth to the array . . .
	RET.push(AZ);
	// Berechnung der Hhe des Objekts in Radiant ...
	// Calculate the height of the object in radiant ...
	var Alt = Math.asin( ( Math.sin(glatDeg / RAD) * Math.sin(geoDecl / RAD) ) + ( Math.cos(glatDeg / RAD) * Math.cos(geoDecl / RAD) *  Math.cos( (LMSTG - geoRA) / RAD) ) );
	// ... Umrechnen in Grad und Ausgeben im Textfeld "Hhe" ...
	// ... Convert to Degree and Output in the text field Hhe ...
	Alt = Alt * RAD;
	// Hhe ins Array ...
	// Altitude to Array . . .
	RET.push(Alt);
	// ... und zurck zum Aufrufer.
	// ... and back to the caller.
	return(RET);
	
}// End of equ2Hor()



 function equ2HorAZ(geoRA, geoDecl, glatDeg, glongDeg, JDLT, jdYear, UT){
	// Berechnung des Teils des vergangenen Jahrhunderts als Dezimalzahl von 0.0 - 1.0 ...
	// Calculate the part of the last century as a decimal from 0.0  1.0 ...
	var T = partOfTheCentury(jdYear, JDLT);
	// Berechnung der Sternzeit in Greenwich um 0h ...
	// Calculation of the stardate in Greenwich at 0h ...
	var GMST0 =  100.46061837 + (36000.770053608 * Number(T[1])) + (0.000387933 * Math.pow(Number(T[1]), 2)) - (Math.pow(Number(T[1]), 3) / 38710000);
	GMST0 = unwindDeg(GMST0 + (15 * (1.00273790935 * UT)));
	// Berechnung der lokalen Sternzeit am Ort der Beobachtung ...
	// Calculation of the local stardate at the place of observation ...
	var LMSTG = unwindDeg(Number(GMST0) + Number(glongDeg));
	// Berechnung der X/Y-Werte fr die tan()-Funktion des Azimuths ...
	// Calculation of the X/Y values for the tan () function of the azimuth ...
	//x = -(Math.cos(glatDeg / RAD) * Math.sin(geoDecl / RAD) ) + ( Math.sin(glatDeg / RAD) * Math.cos(geoDecl / RAD) * Math.cos( (LMSTG - geoRA) / RAD ) );
	//y = Math.cos(geoDecl / RAD) * Math.sin( (LMSTG - geoRA) / RAD );
	var dy = ( Math.sin( (LMSTG - geoRA) / RAD) );
	var dx = ( Math.sin(glatDeg / RAD) * Math.cos( (LMSTG - geoRA) / RAD )) - (Math.cos(glatDeg / RAD) * Math.tan(geoDecl / RAD) );
	// Korrektur des Ergebnisses, da bein Tangens die Quadranten I. + III. sowie II. + IV. dieselben Werte ergeben.
	// Es muss nach Quadrant selektiert werden und dazu werden der Y-Wert und der X-Wert verwendet ...
	// Correction of the result, since tangent the quadrants I. + III. and II. + IV. give the same values.
	// It must be selected by quadrant using the Y-value and the X-value ...
	var AZ = 0.0;
	// I. Quadrant
	if ( dx > 0.0 && dy > 0.0){ 
		AZ = (Math.atan( dy / dx) + Math.PI) * RAD;
	// II. Quadrant
	}else if ( dx < 0.0 && dy > 0.0){
		AZ = (Math.atan( dy / dx) + (2 * Math.PI)) * RAD;
	// III. Quadrant
	}else if ( dx < 0.0 && dy < 0.0){
		AZ = Math.atan( dy / dx)  * RAD;
	// IV. Quadrant
	}else if ( dx > 0.0 && dy < 0.0){
		AZ = (Math.atan( dy / dx) + Math.PI) * RAD;
	}
	// ... dann noch die Sonderflle der Null-Werte bei X und Y, da die Tangenswerte unendlich werden ...
	// ... then the special cases of the zero values at X and Y, since the tangent values become infinite ...
	if (dx == 0.&& dy > 0.0)
		AZ = 90.0;
	else if (dx == 0.0 && dy < 0.0)
		AZ = 180.0;
	else if (dx < 0.0 && dy == 0.0)
		AZ =  270.0;
	else if ( dx > 0.0 && dy == 0.0)
		AZ =  360.0;
		
	return(AZ);

 }// End of equ2HorAZ()



 function equ2HorAlt(geoRA, geoDecl, glatDeg, glongDeg, JDLT, jdYear, UT){
	// Berechnung des Teils des vergangenen Jahrhunderts als Dezimalzahl von 0.0 - 1.0 ...
	// Calculate the part of the last century as a decimal from 0.0  1.0 ...
	var T = partOfTheCentury(jdYear, JDLT);
	// Berechnung der Sternzeit in Greenwich um 0h ...
	// Calculation of the stardate in Greenwich at 0h ...
	var GMST0 =  100.46061837 + (36000.770053608 * Number(T[1])) + (0.000387933 * Math.pow(Number(T[1]), 2)) - (Math.pow(Number(T[1]), 3) / 38710000);
	GMST0 = unwindDeg(GMST0 + (15 * (1.00273790935 * UT)));
	// Berechnung der lokalen Sternzeit am Ort der Beobachtung ...
	// Calculation of the local stardate at the place of observation ...
	var LMSTG = unwindDeg(Number(GMST0) + Number(glongDeg));
	// Berechnung der Hhe des Objekts in Radiant ...
	// Calculate the height of the object in radiant ...
	var Alt = Math.asin( ( Math.sin(glatDeg / RAD) * Math.sin(geoDecl / RAD) ) + ( Math.cos(glatDeg / RAD) * Math.cos(geoDecl / RAD) *  Math.cos( (LMSTG - geoRA) / RAD) ) );
	// ... Umrechnen in Grad und Ausgeben im Textfeld "Hhe" ...
	// ... Convert to Degree and Output in the text field Hhe ...
	Alt = Alt * RAD;
	
	return(Alt);

 }// End of equ2HorAlt()
 
 
 
/* *********************************************************************************
 *	Die Funktion konvertiert quatorial Koordinaten nach Horizontal 
 *	Koordinaten. Dies wird bentigt, um die Hhe und den Azimuth von
 * Objekten, Sterne, Mond, Sonne ... am Himmel anzugeben.
 * Die Funktion darf nicht mit der Funktion objectheight() in derr
 * Berechnungs des Mondauf/Untergangs moonSetAz()moonRiseAz()
 * verwechselt werden.
 *	
 *	bergabewert:
 *		raOrAZDeg	= RA in dezimalen Grad und als Number
 *		decDeg			= Deklination in dezimalen Grad und als Number
 *		glatDeg			= der Breitengrad des Beobachtungsortes in dezimalen Grad
 *									und als Number
 *		
 *	Returnwert:
 *		Array mit den Ergebnissen und Indizes:
 *		[0]	=	Azimuth in deszimalen Grad und als Number
 *		[1]	= Deklination in dezimalen Grad und als Number
 *		
 *	---------------------------------------------------------------------------------------------------
 * The function converts equatorial coordinates to horizontal
 * Coordinates. This is needed to adjust the height and azimuth of
 * Objects, stars, moon, sun . . . in the sky.
 * The function must not be used with the objectheight () function in the
 * Calculation of the moon rise/ Sunset moonSetAz () moonRiseAz ( )
 * to be confused.
 *
 * Transfer value:
 * 		raOrAZDeg = RA in decimal degrees and as number
 * 		decDeg = 		Declination in decimal degrees and as number
 * 		glatDeg = 		the latitude of the observation site in decimal degrees
 * 								and as a number
 *
 * Return value:
 * 		Array with results and indices:
 * 		[ 0] = Azimuth in decimal degrees and as number
 * 		[1 ] = Declination in decimal degrees and as number
  *************************************************************************************** */
function convertEquatorial2Horizontal(raOrAZDeg, decDeg, glatDeg){
	var RET = new Array();										// Der Rckgabewert
																						// The return value
	var RAORAZDEG = Number(raOrAZDeg);		// Der Stundenwinkel RA/AZ in dezimalen Grad
	var DECDEG = Number(decDeg);					//	Die Deklination/Hhe in dezimalen Grad
	var GLATDEG = Number(glatDeg);					// Geographischer Ort des Beobachters
	var SINA = 0.0;															// Der Sinus des Winkels Alpha
	var COSA = 0.0;														// Der Cosinus des Winkels Alpha
	var A = 0.0;																// Der Winkel von SINA
	var ASTRICH = 0.0;													// Der Winkel aus COSA
	var SINH = 0.0;															// Der Sinus der RA/AZ
	var AZH = 0.0;															// Der wahre Azimuth/Hhe in Grad

	// Den Sinus des Winkels Alpha aus RA/AZ und Dec/Hhe und geo. Breite berechnen ...
	// The sine of the angle Alpha of RA/AZ and Dec/Height and geo. Calculate width . . .
	SINA = Math.sin(DECDEG / RAD) * Math.sin(GLATDEG / RAD)+
				 Math.cos(DECDEG / RAD)* Math.cos(GLATDEG / RAD)* Math.cos(RAORAZDEG / RAD);
	// ... und dann den Winkel Alpha in Grad berechnen, das ist die Deklination ...
	// . . . And then calculate the angle alpha in degrees, thats the declination. . .
	A = Math.asin(SINA)* RAD;
	// ... dann den Cosinus des Winkels Alpha aus RA/AZ und Dec/Hhe und geo. Breite berechnen ...
	// . . . then the cosine of the angle Alpha of RA/AZ and Dec/Height and geo. Calculate width . . .
	COSA = (Math.sin(DECDEG / RAD)- Math.sin(GLATDEG / RAD)* Math.sin(A / RAD))/
					(Math.cos(GLATDEG / RAD)* Math.cos(A / RAD));
	// ... und dann den Arcus Cosinus davon in Grad umrechnen ...
	// . . . and then convert the arcus cosine of it into degrees . . .
	ASTRICH = Math.acos(COSA)* RAD;
	// ... dann den Sinus der RA berechnen ...
	// . . . then calculate the sine of the RA . . .
	SINH = Math.sin(RAORAZDEG / RAD);
	// ... und dies ist die Kennziffer fr das Ergebnis des Azimuths zur Deklination ...
	// . . . and this is the index for the result of the azimuth to the declination . . .
	if (SINH < 0.0)
		AZH = ASTRICH;
	else
		AZH = 360.0 - ASTRICH;
	// ... RA/AZ ins Array ...
	// . . . RA/AZ to the array . . .
	RET.push(AZH);
	// Deklination/Hhe ins Array ...
	// Declination /Height to Array . . .
	RET.push(A);
	// ... und zurck zum Aufrufer.
	// ... and back to the caller.
	return(RET);
	
}// End of convertEquatorial2Horizontal()



/* *********************************************************************************
	FEHLERHAFTE FUNKTION

 *	Die Funktion Konvertiert quatorial Koordinaten nach ekliptischen
 *	Koordinaten. Als Ergebnis wird der Lngengrad Lambda und
 * der Breitengrad Beta berechnet. Bercksichtigt wird die ekliptische
 * Schiefe
 *	
 *	bergabewert:
 *		azDeg				= RA in dezimalen Grad und als Number
 *		decDeg			= Deklination als dezimale Grad und als Number
 *		calcDay			= Berechnungstag
 *		calcMonth		= Berechnungsmonat
 *		calcYear			= Berechnungsjahr
 *		
 *	Returnwert:
 *		Array mit den Ergebnissen und Indizes:
 *		[0]	=	Lngengrad als dezimalen Grad und als Number
 *		[1]	= Breitengrad als dezimalen Grad und als Number
 *	---------------------------------------------------------------------------------------------------
 * Convert equatorial coordinates to ecliptic
	* Coordinates. As a result, the longitude lambda and
	* the latitude beta is calculated. Account is taken of the ecliptic
	* skewed
	*
	* Transfer value:
	* azDeg = RA in decimal degrees and as number
	* decDeg = Declination as a Decimal Degree and as a Number
	* CalcDay = Calculation day
	* CalcMonth = Month of calculation
	* CalcYear = Year of calculation
	*
	* Return value:
	* Array with results and indices:
	* [0] = Longitude as decimal degree and as number
	* [1] = latitude as decimal degrees and as number
  *************************************************************************************** */
  
function equ2Eclip(azDeg, decDeg, calcDay, calcMonth, calcYear){
	var ret = new Array();									// Der Rckgabewert
																		// The return value
	var DECDEG = Number(decDeg);				// Der quatoriale Azimuth/RA als Grad und Dezimalzahl
																		// The equatorial azimuth/RA as degrees and decimal value
	var AZDEG = Number(azDeg);					// Die Deklination als Grad und Dezimalzahl
																		// The declination as degree and decimal value
	var CALCDAY = Number(calcDay);				// Der Tag der Kalkulation
																		// Day of calculation
	var CALCMONTH = Number(calcMonth);	// Der Monat der Kalkulation
																		// Month of calculation
	var CALCYEAR = Number(calcYear);			// Das Jahr der Kalkulation
																		// Year of calculation
	var epsilon = 0.0;											// Die ekliptische Schiefe
																		// The ecliptic obliquity
	var y = 0.0;													// Kartesisch y
																		// Cartesian y
	var x = 0.0;													// Kartesisch x
																		// Cartesian x
	var z = 0.0;													// Kartesisch z
																		// Cartesian z
	// Berechne die eklipitsche Schiefe ...
	// Calculate the ecliptic obliquity ...
	epsilon = calcObliquityEcliptic(calcJD(CALCDAY, CALCMONTH,  CALCYEAR, 0, 0, 0, 0, 0, 0));
	// ... und den x-Wert ...
	// and then the x value ...
	x = Math.sin(epsilon / RAD) * Math.sin(DECDEG / RAD) + Math.cos(epsilon / RAD) * Math.cos(DECDEG / RAD) * Math.sin(azDeg / RAD);
	y = Math.cos(DECDEG / RAD) * Math.cos(AZDEG / RAD);
	z = Math.cos(epsilon / RAD) * Math.sin(DECDEG / RAD) - Math.sin(epsilon / RAD) * Math.cos(DECDEG / RAD) * Math.sin(AZDEG / RAD);
	var Beta = Math.asin(z) * RAD;
	// ... und dann in den dezimalen Langengrad umrechnen ...
	// . . . and then convert to the decimal longitude . . .
	console.log(x / Math.cos(Beta / RAD));
	var Lambda = Math.asin(x / Math.cos( Beta / RAD ) ) * RAD;
	
	// ... Grad Lngengrad ins Array ...
	// ... Degrees longitude to array
	ret.push (Lambda);
	// ... Grad Breitengrad ins Array ...
	// ... Degrees altitude to array
	ret.push (Beta);
	// ... und zurck zum Aufrufer
	// ... and back to the caller ...
	return(ret);
	
}// End of equ2Eclip()




/* *********************************************************************************
 *	Die Funktion Konvertiert quatorial Koordinaten nach ekliptischen
 *	Koordinaten. Als Ergebnis wird der Lngengrad Lambda und
 * der Breitengrad Beta berechnet. Bercksichtigt wird die ekliptische
 * Schiefe
 *	
 *	bergabewert:
 *		azDeg				= RA in dezimalen Grad und als Number
 *		decDeg			= Deklination als dezimale Grad und als Number
 *		calcDay			= Berechnungstag
 *		calcMonth		= Berechnungsmonat
 *		calcYear			= Berechnungsjahr
 *		
 *	Returnwert:
 *		Array mit den Ergebnissen und Indizes:
 *		[0]	=	Lngengrad als dezimalen Grad und als Number
 *		[1]	= Breitengrad als dezimalen Grad und als Number
 *	---------------------------------------------------------------------------------------------------
 * Convert equatorial coordinates to ecliptic
	* Coordinates. As a result, the longitude lambda and
	* the latitude beta is calculated. Account is taken of the ecliptic
	* skewed
	*
	* Transfer value:
	* azDeg = RA in decimal degrees and as number
	* decDeg = Declination as a Decimal Degree and as a Number
	* CalcDay = Calculation day
	* CalcMonth = Month of calculation
	* CalcYear = Year of calculation
	*
	* Return value:
	* Array with results and indices:
	* [0] = Longitude as decimal degree and as number
	* [1] = latitude as decimal degrees and as number
  *************************************************************************************** */
function convertEquatorial2Ecliptic(azDeg, decDeg, calcDay, calcMonth, calcYear){
	var ret = new Array();										// Der Rckgabewert
																					// The return value
	var DECDEG = Number(decDeg);				// Der quatoriale Azimuth/RA als Grad und Dezimalzahl
																					// The equatorial azimuth/RA as degrees and decimal value
	var AZDEG = Number(azDeg);						// Die Deklination als Grad und Dezimalzahl
																					// The declination as degree and decimal value
	var CALCDAY = Number(calcDay);				// Der Tag der Kalkulation
																					// Day of calculation
	var CALCMONTH = Number(calcMonth);	// Der Monat der Kalkulation
																					// Month of calculation
	var CALCYEAR = Number(calcYear);			// Das Jahr der Kalkulation
																					// Year of calculation
	var epsilon = 0.0;													// Die ekliptische Schiefe
																					// The ecliptic obliquity
	var sinBeta = 0.0;													// Hilfsvariablen
	var beta = 0.0;														// Auxalary variables
	var y = 0.0;
	var  x = 0.0;
	var lamddaStrich = 0.0;
	// Berechne die eklipitsche Schiefe ...
	// Calculate the ecliptic obliquity ...
	epsilon = calcObliquityEcliptic(calcJD(CALCDAY, CALCMONTH,  CALCYEAR, 0, 0, 0, 0, 0, 0));
	// ... dann den Sinus des Breitengrades ...
	// . . . then the sine of latitude . . .
	sinBeta = Math.sin(AZDEG / RAD)* Math.cos(epsilon / RAD)- 
					 Math.cos(AZDEG / RAD)* Math.sin(epsilon / RAD)* Math.sin(DECDEG / RAD);
	// ... und den Breitengrad in dezimalen Grad ...
	// . . . and the latitude in decimal degrees . . .
	beta = Math.asin( sinBeta)* RAD;
	// ... nun den y-Wert des Lngengrades berechnen ...
	// . . . now calculate the y-value of the longitude . . .
	y = Math.sin(DECDEG / RAD)* Math.cos(epsilon / RAD) +
		  Math.tan(AZDEG / RAD) * Math.sin(epsilon / RAD);
	// ... und den x-Wert ...
	// and then the x value ...
	x = Math.cos(DECDEG / RAD);
	// ... und dann in den dezimalen Langengrad umrechnen ...
	// . . . and then convert to the decimal longitude . . .
	lambdastrich = anotherArcTan(x, y) * RAD;
	// ... Grad Lngengrad ins Array ...
	// ... Degrees longitude to array
	ret.push (lambdastrich);
	// ... Grad Breitengrad ins Array ...
	// ... Degrees altitude to array
	ret.push (beta);
	// ... und zurck zum Aufrufer
	// ... and back to the caller ...
	return(ret);
	
}// End of convertEquatorial2Ecliptic()
