/* **********************************************************************************
 *	Funktionen, die in Init.js verwendet werden und die Berechnung von JD und
 *	MJD betreffen.
 *	Sie werden auch in den Workern bentigt, mssen aber dort in der Datei
 *	enthalten sein.
 *
 *	Des Weiteren sind folgende Funktionen enthalten:
 *	-------------------------------------------------------------------
 *	Int(x)															Ermittelt den Ganzzahlenanteil von x
 *	calculateDateFromMJD()								Berechnet aus dem Modified Julian Date Datum 
 *																		und Uhrzeit
 *	calculateMJD()												Berechnet aus dem Julian Date das Modified Julian
 *																		Date
 *	LPAD()															Fllt eine Zeichenkette links mit Zeichen
 *																		auf
 *	calculateJD1()												Berechnet das Julianische Datum aus aktuellem Datum
 *	calculateDate()												Berechnet Datum und Uhrzeit aus dem Julianischen Datum
 *	---------------------------------------------------------------------------------------------------
 * Functions used in Init.js and the calculation of JD and
 * concern MJD.
 * They are also needed in the workers, but must be there in the file
 * may be included.
 *
 * In addition, the following functions are included:
 *	-------------------------------------------------------------------
 * Int (x)                                                      
 * calculateDateFromMJD () 		    Calculated from the Modified Julian Date Date 
 *                                        
 * calculateMJD ()    		     				Calculates the Modified Julian from the Julian Date
 *                                    
 * LPAD ()  										Fills a character string on the left with characters
 *														on
 * calculateJD1 ()          					Calculates the Julian date from current date
 * calculateDate (JD)         				Calculates date and time from the Julian date
   ******************************************************************************* */


/* ******************************************************
	Die Funktion fllt eine Zeichenketten mit Zahl vorne
	mit n-Zeichen auf.	Z.B. 1 -> 01.
	
	bergabewert:
	--------------------
		izahl 				= 	Die Zahl ohne fhrende Nullen
		ianzStellen		= 	Die gewnschte Anzahl von Stellen
		sFuelzeichen	=	Das gewnschet fhrende Zeichen
	
	Rckgabewert:
	---------------------
									Z.B. "01" oder "0001"
	----------------------------------------------------------------
	The function fills a string with number in front
	with n-signs.	E.g. 1 -> 01.
	
	Transfer value:
	--------------------
		izahl    =  The number without leading zeros
		ianzPlaces  =  The desired number of posts
		sFuelmark = The desired leading character
	
	Return value:
	---------------------
									E.g. 01 or 0001
   *************************************************** */
function LPAD( iZahl, iAnzStellen, sFuellzeichen ){
    var sZahl = iZahl + "";
	// Durchlaufe die Zeichenkette solange bis die gewnschte
	// Anzahl von Zeichen erreicht ist ...
	// Run the string until the desired one
	// Number of characters reached ...
    while( sZahl.length < iAnzStellen )
		// ... und flle den Ergebnisstring sZahl links vor der Zahl
		// mit dem Fllzeichen auf ...
		// ... and fill in the result string sNumber left before the number
		// with the fill mark on ...
        sZahl = sFuellzeichen + sZahl;
	// ... und dann zurck zum Aufrufer.
	// ... and then back to the caller.
    return sZahl;
	
}// End of LPAD()



/* ******************************************************
	Gibt einen Integer Wert zurck. Bei negativen 
	Werten wird aufgerundet -3.2 = -3.
	Bei positiver abgerundet 3.2 = 3
	
	bergabewert:
	--------------------
		x 				= 	Die zu rundende Zahl
	
	Rckgabewert:
	---------------------
						= Die gerundete Zahl
	----------------------------------------------------------------
	Returns an integer value. In the case of negative 
	Values are rounded up -3.2 = -3.
	With positive rounded 3.2 = 3
	
	Transfer value:
	--------------------
		x     =  The number to be rounded
	
	Return value:
	---------------------
						= The rounded number
   *************************************************** */
function Int(x){
	if (x < 0) { 
		return(Math.ceil(x));	// Nchsthhere Ganzzahl (Aufrundung)
										// Next higher integer (rounding) 
	} else 
		return(Math.floor(x));// Nchstniedrigere Ganzzahl (Abrunden)
										// Next lower integer (rounding) 
}// End of Int()



/* ******************************************************
	Die Funktion Ermittelt das Datum aus dem Julianische Datum.
	Nach der Ephemeriden Rechnung von Oliver Montenbruck
	bergeben wird das Julianische Datum und Rckgabe ist
	Tag, Monat, Jahr und Uhrzeit in einem Array.
	
	bergabewerte:
	--------------------
			JD		=	Julianisches Datum als Gleitkommazahl
		
	Rckgabewert:
	---------------------
	Array Datum	=	[day, month, year, hour, minute, second, msecond]
							Index 0 - 6
	----------------------------------------------------------------
	The function Gets the date from the Julian date.
	Based on the Ephemeris Calculation by Oliver Montenbruck
	The Julian date is passed and the return is
	Day, month, year and time in an array.
	
	Transfer values:
	--------------------
			JD 		 = Julian date as floating point number
		
	Return value:
	---------------------
	Array Datum = [day, month, year, hour, minute, second, msecond]
							Index 0  6
   *************************************************** */
function calculateDate(JD){
	// Variablen Deklaration und Definition ...
	// Variable declaration and definition ...
	var day = 0; var month = 0; var year = 0;
	var hour = 0; var minute = 0; var second = 0; var msecond = 0;
	var a = 0; var b = 0; var c = 0; var d = 0; var e = 0; var f = 0;
	var x = 2299161;
	// Korrekturfaktor, da bei der Rckrechnung 1 ms im Ergebnis
	// unterschied ist. Dazu JD + 1 / Millisekunden pro Tag
	// Correction factor, because at the back calculation 1 ms in the result
	// is different. Add JD + 1 / milliseconds per day
	JD += 0.0000000115740740740;
	// ... Datumsberechnung aus dem Ganzzahlenanteil des julianischen Datums ...
	// // ... Date calculation from the integer portion of the Julian date ...
	a = Math.floor(JD + 0.5);
	if ( a < x) { 
		c = a + 1524;
	}else if ( a >= x){
		b = Math.floor( (a - 1867216.25) / 36524.25 );
		c = a + b - Math.floor( b / 4 ) + 1525;
	}
	// ... Berechnung der Hilfsgren ...
	// ... Calculation of auxiliary variables ...
	d = Math.floor( ( c - 122.1 ) / 365.25 );
	e = Math.floor ( d * 365.25 );
	f = Math.floor ( ( c - e ) / 30.6001 );
	// ... Berechnung des Datums ...
	// ... Calculation of the date ...
	day = Math.trunc(c - e - Math.floor( f * 30.6001 ) + ( JD + 0.5 - a ));
	month = f - 1 - 12 * Math.floor ( f / 14);
	year = d - 4715 - Math.floor ( ( 7 + month ) / 10 );
	// ... Uhrzeit Berechnung aus den Nachkommastellen des Julianischen Datums ...
	// ... Time Calculation from the decimal places of the Julian date ...
	var jdRest = Math.abs( ( ( JD + 0.5 )  - Math.trunc(JD + 0.5) ) );
	hour = Math.abs(Math.trunc(24. * jdRest));
	jdRest = (24. * jdRest) - hour;
	minute = Math.trunc(60. * jdRest);
	jdRest = (60. * jdRest) - minute;
	second = Math.trunc(60. * jdRest);
	jdRest = (60. * jdRest) - second;
	msecond = Math.trunc(1000. * jdRest);
	// ... und die Rckgabe des Datums mit Uhrzeit als Array. Index 0 - 6.
	// ... and the return of the date with time as array. Index 0  6.
	return [day, month, year, hour, minute, second, msecond];
	
}// End of calculateDate()



/* ******************************************************
	Die Funktion Ermittelt das Julianische Datum
	Nach der Ephemeriden Rechnung. Verwendet
	wird das Datum als Integer Werte und die Uhrzeit
	als Geltkommazahl fr den Tag.
	
	bergabewert:
	--------------------
		day		=	Tag als Integer
		month	=	Monat als Integer
		year		=	Jahreszahl als Integer
		UT		=	Greenwich Uhrzeit als Gleitkommazahl am Berechnungstag
	
	Rckgabewert:
	---------------------
		JD		=	Julianisches Datum als Gleitkommazahl fr
						das angegebene Datum
	----------------------------------------------------------------
	The function Determines the Julian date
	According to the Ephemeris account. Used
	is the date as integer values and the time
	as a valid point number for the day.
	
	Transfer value:
	--------------------
		day  		= Tag as integer
		month 	= month as integer
		year  	= year as integer
		UT  		= Greenwich time as floating point number on the calculation day
	
	Return value:
	---------------------
		JD  = Julian date as floating point number for
						the date indicated
   *************************************************** */
function calculateJD1(day,month,year, UT){
  // Variablen der Hilfsgren ...
  // Variables of auxiliary variables ...
  var y = 0; var m = 0; var B = 0;
  // Zu berechnendes Datumsobjekt aus Tag, Monat u. Jahr ...
  // Date object to be calculated from day, month and year ...
  var date = new Date(year, month, day);
  // ... Date Objekte fr die Umstellung von Julianischen- auf
  // Gregorianischen Kalende ...
  // ... Date objects for switching from Julian to
  // Gregorian Calendar ...
  var date1 = new Date("1582", "10", "4");
  var date2 = new Date("1582", "10", "15")
  // ... Hilfsgren berechnen ...
  // ... Calculate auxiliary variables ...
  if (month <= 2) {
	y = year - 1;
	m = month + 12; 
  }else{
	y = year;
	m = month;
  }
  /* **************************************************
   * Beschrnkt man sich bei den Berechnungen nur auf den
   * Zeitraum vom 01.03.1900 - 28.02.2100, dann kann man
   * B = -15 setzen.
   * The calculations are limited to the
   * Period from 01.03.1900  28.02.2100, then you can
   * B = -15.
   * **************************************************/
  // ... bergebenes Datum liegt im Julianischen Bereich ...
  // ... Passed date is in the Julian range ...
  if (date <= date1){
	B = -2;
  // ... bergebenes Datum liegt im Gregorianischen Bereich ...
  // ... // Passed date is in the Gregorian range ...
  }else if (date >= date2){
	B = Math.floor(y/400) - Math.floor(y/100);
  }
  // ... UT = GMT, also Lokalzeit - DST (Daylight Savings Time) - Zeitzone ...
  // ... und zurck zum Aufrufer.
  // ... UT = GMT, local time  DST (Daylight Savings Time)  time zone ...
  // ... and back to the caller.
  return (Math.floor(365.25 * y) + Math.floor(30.6001 * (m + 1)) + B + 1720996.5 + day + (UT/24));

}// End of calculateJD1()



/* ******************************************************
	Die Funktion ermittelt aus dem Julianischen Datum das
	Modifizierte Julianische Datumab 1900.
	
	bergabewert:
	--------------------
		JD 				= 	Julianisches Datum als Gleitkommazahl
								z.B. 2459736.8725618864
	
	Rckgabewert:
	---------------------
		MJD				=	Modified Julian Date als Gleitkommazahl
								z. B. 59736.37256189808
	----------------------------------------------------------------
	The function determines from the Julian date the
	Modified Julian date from 1900.
	
	Transfer value:
	--------------------
		JD     =  Julian date as floating point number
								e.g. 2459736.8725618864
	
	Return value:
	---------------------
		MJD    = Modified Julian Date as floating point number
								e.g. 59736.37256189808
   *************************************************** */
function calculateMJD(JD)
{
	// Korrekturfaktor, da bei der Rckrechnung 1 ms im Ergebnis
	// unterschied ist. Dazu JD + 1 / Microsekunden pro Tag
	// Correction factor, because at the back calculation 1 ms in the result
	// is different. Add JD + 1 / microseconds per day
	JD += 0.0000000115740740740;
	// ... und Wert fr 0.1.1900 = 2400000,5 abziehen, dann zurck zum Aufrufer.
	// ... and subtract value for 0.1.1900 = 2400000.5, then return to the caller.
	return (JD - 2400000.5);
	
}// End of calculateMJD()




/* ******************************************************
	Die Funktion Ermittelt das Modified Julianische Datum
	aus dem Julianischen Datums.

	
	bergabewert:
	--------------------
		JD 				= 	Julianisches Datum als Gleitkommazahl
								z.B. 2459736.8725618864
	
	Rckgabewert:
	---------------------
		Datum			=	Array mit den Datums und Uhrzeitwerten
		Datum[0..6]	=	[day, month, year, hour, minute, second, msecond]
	----------------------------------------------------------------
	The function Determines the Modified Julian Date
	from the Julian date.

	
	Transfer value:
	--------------------
		JD     =  Julian date as floating point number
								e.g. 2459736.8725618864
	
	Return value:
	---------------------
		Date   = Array with date and time values
		Datum[0..6] = [day, month, year, hour, minute, second, msecond]
   *************************************************** */
function calculateDateFromMJD(MJD){
	// Variablen definieren und initialisieren ...
	// Define and initialize variables ...
	var day = 0; var month = 0; var year = 0;
	var hour = 0; var minute = 0; var second = 0; var msecond = 0;
	var K = 0;
	// Werte des Datums ermitteln ...
	// Determine values of the date ...
	year = Int ( (MJD - 15078.2) / 365.25 );
	month = Int ( ( MJD - 14956.1 - Int (year * 365.25) ) / 30.6001 );
	day = Math.trunc(MJD - 14956 - Int ( year * 365.25 ) - Int ( month * 30.6001 ));
	// ... Korrekturwerte zuweisen ...
	// ... Assign correction values ...
	if ( (month == 14) || (month == 15) )
		K = 1;
	else 
		K = 0;
	// ... mit der Korrektur Jahr und Monat berechnen ...
	// ... with the correction to calculate year and month ...
	year += (K + 1900);
	month = month - 1 - (K * 12);
	// ... nun die Uhrzeit Berechnung aus den Nachkommastellen des Julianischen Datums ...
	// ... now the time Calculation from the decimal places of the Julian date ...
	var jdRest = Math.abs( ( ( MJD )  - Math.trunc(MJD) ) );
	hour = Math.abs(Math.trunc(24. * jdRest));
	jdRest = (24. * jdRest) - hour;
	minute = Math.trunc(60. * jdRest);
	jdRest = (60. * jdRest) - minute;
	second = Math.trunc(60. * jdRest);
	jdRest = (60. * jdRest) - second;
	msecond = Math.trunc(1000. * jdRest);
	// ... und Rckgabe Array von Datum und Uhrzeit als einzelne Werte.
	// Index 0 - 6. 
	// ... an return array of date and time as individual values.
	// Index 0  6.
	return [day, month, year, hour, minute, second, msecond];
	
}// End of calculateDateFromMJD()